@@ -1,30 +1,21 @@
 // Copyright (c) 2023 Yuki Kimoto
 // MIT License
 
-#ifdef __linux__
-  // Enable X/Open System Interfaces (SUSv4) functions and POSIX.1-2008 standard functions
-  #define _XOPEN_SOURCE 700
-
-  // Enable BSD and System V extensions
-  #define _DEFAULT_SOURCE
-#endif
-
-
 #include "spvm_native.h"
 #include "spvm_socket_util.h"
 
 #include <assert.h>
 
-static const char* FILE_NAME = "Sys/Socket/In_addr.c";
+const char* FILE_NAME = "Sys/Socket/In_addr.c";
 
 int32_t SPVM__Sys__Socket__In_addr__new(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t error_id = 0;
+  int32_t e = 0;
   
-  struct in_addr* address = env->new_memory_block(env, stack, sizeof(struct in_addr));
-  
-  void* obj_address = env->new_pointer_object_by_name(env, stack, "Sys::Socket::In_addr", address, &error_id, __func__, FILE_NAME, __LINE__);
-  if (error_id) { return error_id; }
+  struct in_addr* address = env->new_memory_stack(env, stack, sizeof(struct in_addr));
+
+  void* obj_address = env->new_pointer_object_by_name(env, stack, "Sys::Socket::In_addr", address, &e, __func__, FILE_NAME, __LINE__);
+  if (e) { return e; }
   
   stack[0].oval = obj_address;
   
@@ -39,7 +30,7 @@ int32_t SPVM__Sys__Socket__In_addr__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   assert(address);
   
-  env->free_memory_block(env, stack, address);
+  env->free_memory_stack(env, stack, address);
   env->set_pointer(env, stack, obj_address, NULL);
   
   return 0;
@@ -65,7 +56,7 @@ int32_t SPVM__Sys__Socket__In_addr__set_s_addr(SPVM_ENV* env, SPVM_VALUE* stack)
   struct in_addr* address = env->get_pointer(env, stack, obj_address);
   
   assert(address);
-  
+
   address->s_addr = stack[1].ival;
   
   return 0;
