@@ -1,30 +1,21 @@
 // Copyright (c) 2023 Yuki Kimoto
 // MIT License
 
-#ifdef __linux__
-  // Enable X/Open System Interfaces (SUSv4) functions and POSIX.1-2008 standard functions
-  #define _XOPEN_SOURCE 700
-
-  // Enable BSD and System V extensions
-  #define _DEFAULT_SOURCE
-#endif
-
-
 #include "spvm_native.h"
 #include "spvm_socket_util.h"
 
 #include <assert.h>
 
-static const char* FILE_NAME = "Sys/Socket/Ipv6_mreq.c";
+const char* FILE_NAME = "Sys/Socket/Ipv6_mreq.c";
 
 int32_t SPVM__Sys__Socket__Ipv6_mreq__new(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t error_id = 0;
+  int32_t e = 0;
   
-  struct ipv6_mreq* multi_request = env->new_memory_block(env, stack, sizeof(struct ipv6_mreq));
+  struct ipv6_mreq* multi_request = env->new_memory_stack(env, stack, sizeof(struct ipv6_mreq));
 
-  void* obj_multi_request = env->new_pointer_object_by_name(env, stack, "Sys::Socket::Ipv6_mreq", multi_request, &error_id, __func__, FILE_NAME, __LINE__);
-  if (error_id) { return error_id; }
+  void* obj_multi_request = env->new_pointer_object_by_name(env, stack, "Sys::Socket::Ipv6_mreq", multi_request, &e, __func__, FILE_NAME, __LINE__);
+  if (e) { return e; }
   
   stack[0].oval = obj_multi_request;
   
@@ -40,7 +31,7 @@ int32_t SPVM__Sys__Socket__Ipv6_mreq__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack)
   
   assert(multi_request);
   
-  env->free_memory_block(env, stack, multi_request);
+  env->free_memory_stack(env, stack, multi_request);
   env->set_pointer(env, stack, obj_multi_request, NULL);
   
   return 0;
@@ -48,7 +39,7 @@ int32_t SPVM__Sys__Socket__Ipv6_mreq__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack)
 
 int32_t SPVM__Sys__Socket__Ipv6_mreq__ipv6mr_multiaddr(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t error_id = 0;
+  int32_t e = 0;
   
   void* obj_self = stack[0].oval;
   
@@ -56,11 +47,11 @@ int32_t SPVM__Sys__Socket__Ipv6_mreq__ipv6mr_multiaddr(SPVM_ENV* env, SPVM_VALUE
   
   struct in6_addr address = multi_request->ipv6mr_multiaddr;
 
-  struct in6_addr* address_ret = env->new_memory_block(env, stack, sizeof(struct in6_addr));
+  struct in6_addr* address_ret = env->new_memory_stack(env, stack, sizeof(struct in6_addr));
   *address_ret = address;
 
-  void* obj_address_ret = env->new_pointer_object_by_name(env, stack, "Sys::Socket::In6_addr", address_ret, &error_id, __func__, FILE_NAME, __LINE__);
-  if (error_id) { return error_id; }
+  void* obj_address_ret = env->new_pointer_object_by_name(env, stack, "Sys::Socket::In6_addr", address_ret, &e, __func__, FILE_NAME, __LINE__);
+  if (e) { return e; }
   
   stack[0].oval = obj_address_ret;
   
@@ -83,7 +74,7 @@ int32_t SPVM__Sys__Socket__Ipv6_mreq__set_ipv6mr_multiaddr(SPVM_ENV* env, SPVM_V
 
 int32_t SPVM__Sys__Socket__Ipv6_mreq__ipv6mr_interface(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t error_id = 0;
+  int32_t e = 0;
   
   void* obj_self = stack[0].oval;
   
